// Пример для одного светодиода:                                                       //
#include <Wire.h>                                                                      // Подключаем библиотеку Wire. Для работы с Arduino/Piranha, эту библиотеку можно не подключать.
#include <iarduino_Metro.h>                                                            // Подключаем библиотеку.
                                                                                       //
uint8_t sum;                                                                           // Объявляем переменную для хранения количества найденных модулей Metro.
                                                                                       //
void setup(){                                                                          //
//  Определяем все модули на шине I2C и сохраняем их количество в переменную sum:      //
    sum=iarduino_Metro_Start();                                                        // В качестве аргумента функции iarduino_Metro_Start() можно указать номер адресного вывода (если вывод не указан, то будет использован D12).
//  Теперь нам доступен массив Metro содержащий sum элементов для управления модулями. // Metro[0] управляет ближайшим к Arduino модулем, Metro[1] управляет следующим модулем и т.д до последнего модуля Metro[sum-1].
                                                                                       //
//  Проверяем наличие модулей Metro на шине I2C:                                       //
    while(sum==0){;}                                                                   // Если модули Metro не обнаружены, то входим в бесконечный цикл while, тогда цикл loop выполняться не будет.
    while(Metro[0].model!=MOD_RGB){;}                                                  // Если ближайший к Arduino модуль Metro не является светодиодом, то так же входим в бесконечный цикл while.
                                                                                       //
//  Включаем светодиод (цвет по умолчанию - белый):                                    //
    Metro[0].on();                                                                     // Включаем светодиод без указания цвета (по умолчанию установится белый цвет).
    delay(3000);                                                                       // Ждём 3 секунды.
    Metro[0].off();                                                                    // Выключаем светодиод.
    delay(1000);                                                                       // Ждём 1 секунду.
//  Включаем светодиод с указанием цвета (0xFF0000 - красный):                         //
    Metro[0].on( 0xFF0000 );                                                           // Включаем красный цвет.
    delay(3000);                                                                       // Ждём 3 секунды.
    Metro[0].off();                                                                    // Выключаем светодиод.
    delay(1000);                                                                       // Ждём 1 секунду.
//  Включаем светодиод на определённое время (будет включён 1000 миллисекунд):         //
    Metro[0].on( 0x00FF00, 1000);                                                      // Включаем зелёный цвет на 1000 мс (1 сек) после чего светодиод сам выключится.
    delay(3000);                                                                       // Ждём 3 секунды (так как светодиод будет светиться только 1 секунду, то оставшиеся 2 секунды ожидания он будет выключен).
//  Заставляем светодиод постоянно мигать:                                             //
    Metro[0].on( 0x0000FF, 100, 200);                                                  // Мигаем синим цветом, светодиод будет постоянно включаться на 100 мс и потухать на 200 мс.
    delay(3000);                                                                       // Ждём 3 секунды.
//  Заставляем светодиод мигнуть 5 раз и выключиться:                                  //
    Metro[0].on( 0xFFFFFF, 100, 200, 5);                                               // Мигаем белым цветом, светодиод будет включаться на 100 мс и потухать на 200 мс, а после 5 включений/выключений он перестанет мигать.
    delay(3000);                                                                       // Ждём 3 секунды.
//  Альтернативный способ задания цвета:                                               //
    Metro[0].on( RGB(255,0,255) , 1000);                                               // Включаем светодиод фиолетовым цветом на 1000 мс (1 сек) после чего он сам выключится.
}                                                                                      //
                                                                                       //
void loop(){                                                                           //
/*                                                                                     //
 *   Metro[0].on(); - включить светодиод.                                              // Если цвет не указан, то светодиод включит белый цвет.
 *   Metro[0].on( цвет ); - включить указанный цвет.                                   // Цвет указывается как в Photoshop, например, 0xFF5500 - красный 0xFF / зелёный 0x55 / синий 0x00.
 *   Metro[0].on( цвет , длительность ); - включить цвет на указанное время.           // Длительность свечения указывается в миллисекундах от 0 до 25500 мс, например, 1000 - светодиод будет светиться 1 секунду после чего выключиться.
 *   Metro[0].on( цвет , длительность , пауза ); - светодиод будет постоянно мигать.   // Длительность свечения и пауза между свечениями указываются в миллисекундах от 0 до 25500 мс.
 *   Metro[0].on( цвет , длительность , пауза , количество ); - мигнуть несколько раз. // Светодиод будет мигать не постоянно, а указанное количество раз от 1 до 255.
 *   Metro[0].off(); - выключить светодиод                                             // 
 *                                                                                     //
 *   цвет можно задать числом от 0x000000 до 0xFFFFFF                                  // Старшие 2 разряда - яркость красного цвета, стредние 2 разряда - яркость зелёного цвета и младшие 2 разряда - яркость синего цвета.
 *   а можно через функцию RGB( красный , зелёный , синий)                             // Каждый цвет представлен числом от 0 (0x00) до 255 (0xFF).
 */                                                                                    //
}                                                                                      //